@@ -73,16 +73,15 @@ sub allow_rpc_access ($self,$method) {
     if (not exists $allow{$method}){
         return 0;
     }
-
     for ($allow{$method}){
         /1/ && return 1;
+        return 1 if ($self->user->isUserAuthenticated);
         /3/ && do {
             my $plugin = $self->rpcParams->[0];
             if ($self->config->instantiatePlugin($plugin,$self->user)->mayAnonymous){
                 return 1;    
             }
         };
-        return $self->user->isUserAuthenticated;
     }
     return 0;
 };
